@@ -17,7 +17,7 @@
 %                                 July 2000                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright @ 2000 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -158,30 +158,29 @@ static MagickBooleanType
 %    o exception: return any errors or warnings in this structure.
 %
 */
-static int CompareMagickInfoSize(const void *a,const void *b)
+
+static int CompareMagickInfoExtent(const void *a,const void *b)
 {
   MagicInfo
     *ma,
     *mb;
 
+  MagickOffsetType
+    delta;
+
   ma=(MagicInfo *) a;
   mb=(MagicInfo *) b;
+  delta=(MagickOffsetType) mb->length-(MagickOffsetType) ma->length;
   if (ma->offset != mb->offset)
     {
-      MagickOffsetType
-        max_offset;
-
       /*
-        When the offset is near the start we first search a bit further
-        in the stream.
+        Offset is near the start? Let's search a bit further in the stream.
       */
-      max_offset=ma->offset > mb->offset ? ma->offset : mb->offset;
-      if (max_offset <= 10)
-        return((int) (mb->offset-ma->offset));
-      else
-        return((int) (ma->offset-mb->offset));
+      delta=ma->offset-mb->offset;
+      if ((ma->offset > mb->offset ? ma->offset : mb->offset) <= 10)
+        delta=mb->offset-ma->offset;
     }
-  return((int) (mb->length-ma->length));
+  return(delta > INT_MAX ? 0 : (int) delta);
 }
 
 static LinkedListInfo *AcquireMagicList(ExceptionInfo *exception)
@@ -192,7 +191,7 @@ static LinkedListInfo *AcquireMagicList(ExceptionInfo *exception)
   MagickStatusType
     status;
 
-  register ssize_t
+  ssize_t
     i;
 
   list=NewLinkedList(0);
@@ -205,7 +204,7 @@ static LinkedListInfo *AcquireMagicList(ExceptionInfo *exception)
     MagicInfo
       *magic_info;
 
-    register const MagicMapInfo
+    const MagicMapInfo
       *p;
 
     p=MagicMap+i;
@@ -225,7 +224,7 @@ static LinkedListInfo *AcquireMagicList(ExceptionInfo *exception)
     magic_info->length=p->length;
     magic_info->exempt=MagickTrue;
     magic_info->signature=MagickCoreSignature;
-    status&=InsertValueInSortedLinkedList(list,CompareMagickInfoSize,
+    status&=InsertValueInSortedLinkedList(list,CompareMagickInfoExtent,
       NULL,magic_info);
     if (status == MagickFalse)
       (void) ThrowMagickException(exception,GetMagickModule(),
@@ -280,9 +279,12 @@ static MagickBooleanType IsMagicCacheInstantiated()
 MagickExport const MagicInfo *GetMagicInfo(const unsigned char *magic,
   const size_t length,ExceptionInfo *exception)
 {
-  register const MagicInfo
+  const MagicInfo
     *p;
 
+  MagickOffsetType
+    offset;
+
   assert(exception != (ExceptionInfo *) NULL);
   if (IsMagicListInstantiated(exception) == MagickFalse)
     return((const MagicInfo *) NULL);
@@ -298,7 +300,8 @@ MagickExport const MagicInfo *GetMagicInfo(const unsigned char *magic,
       p=(const MagicInfo *) GetNextValueInLinkedList(magic_cache);
       while (p != (const MagicInfo *) NULL)
       {
-        if (((size_t) (p->offset+p->length) <= length) &&
+        offset=p->offset+(MagickOffsetType) p->length;
+        if ((offset <= (MagickOffsetType) length) &&
             (memcmp(magic+p->offset,p->magic,p->length) == 0))
           break;
         p=(const MagicInfo *) GetNextValueInLinkedList(magic_cache);
@@ -321,7 +324,8 @@ MagickExport const MagicInfo *GetMagicInfo(const unsigned char *magic,
   while (p != (const MagicInfo *) NULL)
   {
     assert(p->offset >= 0);
-    if (((size_t) (p->offset+p->length) <= length) &&
+    offset=p->offset+(MagickOffsetType) p->length;
+    if ((offset <= (MagickOffsetType) length) &&
         (memcmp(magic+p->offset,p->magic,p->length) == 0))
       break;
     p=(const MagicInfo *) GetNextValueInLinkedList(magic_list);
@@ -330,7 +334,7 @@ MagickExport const MagicInfo *GetMagicInfo(const unsigned char *magic,
   if (p != (const MagicInfo *) NULL)
     {
       LockSemaphoreInfo(magic_cache_semaphore);
-      InsertValueInSortedLinkedList(magic_cache,CompareMagickInfoSize,
+      (void) InsertValueInSortedLinkedList(magic_cache,CompareMagickInfoExtent,
         NULL,p);
       UnlockSemaphoreInfo(magic_cache_semaphore);
     }
@@ -348,7 +352,7 @@ MagickExport const MagicInfo *GetMagicInfo(const unsigned char *magic,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  GetMagicPatternExtent() returns the the extent of the buffer that is
+%  GetMagicPatternExtent() returns the extent of the buffer that is
 %  required to check all the MagickInfos. It returns zero if the list is empty.
 %
 %  The format of the GetMagicPatternExtent method is:
@@ -362,33 +366,34 @@ MagickExport const MagicInfo *GetMagicInfo(const unsigned char *magic,
 */
 MagickExport size_t GetMagicPatternExtent(ExceptionInfo *exception)
 {
-  register const MagicInfo
+  const MagicInfo
     *p;
 
-  size_t
-    magickSize,
-    max;
+  MagickOffsetType
+    max_offset,
+    offset;
 
   static size_t
-    size=0;
+    extent = 0;
 
   assert(exception != (ExceptionInfo *) NULL);
-  if ((size != 0) || (IsMagicListInstantiated(exception) == MagickFalse))
-    return(size);
+  if ((extent != 0) || (IsMagicListInstantiated(exception) == MagickFalse))
+    return(extent);
   LockSemaphoreInfo(magic_list_semaphore);
   ResetLinkedListIterator(magic_list);
-  max=0;
   p=(const MagicInfo *) GetNextValueInLinkedList(magic_list);
-  while (p != (const MagicInfo *) NULL)
+  for (max_offset=0; p != (const MagicInfo *) NULL; )
   {
-    magickSize=(size_t) (p->offset+p->length);
-    if (magickSize > max)
-      max=magickSize;
+    offset=p->offset+(MagickOffsetType) p->length;
+    if (offset > max_offset)
+      max_offset=offset;
     p=(const MagicInfo *) GetNextValueInLinkedList(magic_list);
   }
-  size=max;
+  if (max_offset > (MagickOffsetType) MAGICK_SSIZE_MAX)
+    return(0);
+  extent=(size_t) max_offset;
   UnlockSemaphoreInfo(magic_list_semaphore);
-  return(size);
+  return(extent);
 }
 
 /*
@@ -447,10 +452,10 @@ MagickExport const MagicInfo **GetMagicInfoList(const char *pattern,
   const MagicInfo
     **aliases;
 
-  register const MagicInfo
+  const MagicInfo
     *p;
 
-  register ssize_t
+  ssize_t
     i;
 
   /*
@@ -523,7 +528,7 @@ extern "C" {
 
 static int MagicCompare(const void *x,const void *y)
 {
-  register const char
+  const char
     *p,
     *q;
 
@@ -542,10 +547,10 @@ MagickExport char **GetMagicList(const char *pattern,size_t *number_aliases,
   char
     **aliases;
 
-  register const MagicInfo
+  const MagicInfo
     *p;
 
-  register ssize_t
+  ssize_t
     i;
 
   /*
@@ -679,7 +684,7 @@ MagickExport MagickBooleanType ListMagicInfo(FILE *file,
   const MagicInfo
     **magic_info;
 
-  register ssize_t
+  ssize_t
     i;
 
   size_t
@@ -775,7 +780,7 @@ MagickPrivate MagickBooleanType MagicComponentGenesis(void)
 
 static void *DestroyMagicElement(void *magic_info)
 {
-  register MagicInfo
+  MagicInfo
     *p;
 
   p=(MagicInfo *) magic_info;
